DEBUG = 10
INFO = 20
NOTICE = INFO
WARNING = 30
ERROR = 40
SUCCESS = 10

LEVELS = {
    SUCCESS: 'success',
    NOTICE: 'info',
    WARNING: 'warning',
    ERROR: 'error',
    INFO: 'info',
    DEBUG: 'debug',
}